compose-stubs
=============

`Typing stubs <https://peps.python.org/pep-0561/#stub-only-packages>`_
for |compose|_.

.. |compose| replace:: ``compose``
.. _compose: https://pypi.org/project/compose


Versioning
----------

This library's version numbers follow the `SemVer 2.0.0
specification <https://semver.org/spec/v2.0.0.html>`_.


Installation
------------

::

    pip install compose-stubs
